LRScheduler
===========

.. currentmodule:: pykeen.lr_schedulers

.. autoclass:: LRScheduler
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~LRScheduler.get_last_lr
      ~LRScheduler.get_lr
      ~LRScheduler.load_state_dict
      ~LRScheduler.print_lr
      ~LRScheduler.state_dict
      ~LRScheduler.step

   .. rubric:: Methods Documentation

   .. automethod:: get_last_lr
   .. automethod:: get_lr
   .. automethod:: load_state_dict
   .. automethod:: print_lr
   .. automethod:: state_dict
   .. automethod:: step
